==> gridplayer-0.1.0-py3-none-any.whl: gridplayer/dialogs/messagebox.py <==
from PyQt5.QtCore import Qt
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QMessageBox

from gridplayer.resources import ICONS


class QCustomMessageBox(QMessageBox):
    _icons = {
        QMessageBox.Question: ICONS["custom/030-question"],
        QMessageBox.Critical: ICONS["basic/031-cancel"],
    }

    def __init__(
        self,
        icon,
        title,
        text,
        buttons=QMessageBox.NoButton,
        parent=None,
        f=Qt.Dialog | Qt.MSWindowsFixedSizeDialogHint,
    ):
        super().__init__(icon, title, text, buttons, parent, f)

        for btn in self.buttons():
            btn.setIcon(QIcon())

        self.setIconPixmap(self._icons[icon].pixmap(64, 64))

    @classmethod
    def critical(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Critical, title, text, buttons, parent).exec_()

    @classmethod
    def information(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Information, title, text, buttons, parent).exec_()

    @classmethod
    def question(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Yes | QMessageBox.No,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Question, title, text, buttons, parent).exec_()

    @classmethod
    def warning(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Warning, title, text, buttons, parent).exec_()

==> gridplayer-0.1.1-py3-none-any.whl: gridplayer/dialogs/messagebox.py <==
from PyQt5.QtCore import Qt
from PyQt5.QtGui import QIcon
from PyQt5.QtWidgets import QMessageBox


class QCustomMessageBox(QMessageBox):
    def __init__(
        self,
        icon,
        title,
        text,
        buttons=QMessageBox.NoButton,
        parent=None,
        f=Qt.Dialog | Qt.MSWindowsFixedSizeDialogHint,
    ):
        super().__init__(icon, title, text, buttons, parent, f)

        for btn in self.buttons():
            btn.setIcon(QIcon())

        icons = {
            QMessageBox.Question: QIcon.fromTheme("question"),
            QMessageBox.Critical: QIcon.fromTheme("close"),
        }

        self.setIconPixmap(icons[icon].pixmap(64, 64))

    @classmethod
    def critical(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Critical, title, text, buttons, parent).exec_()

    @classmethod
    def information(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Information, title, text, buttons, parent).exec_()

    @classmethod
    def question(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Yes | QMessageBox.No,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Question, title, text, buttons, parent).exec_()

    @classmethod
    def warning(
        cls,
        parent,
        title,
        text,
        buttons=QMessageBox.Ok,
        defaultButton=QMessageBox.NoButton,
    ):
        return cls(QMessageBox.Warning, title, text, buttons, parent).exec_()
